@@ -1,28 +1,25 @@
-#' @title Plot for PredictionClust
+#' @title Plots for Cluster Predictions
 #'
 #' @description
-#' Generates plots for [mlr3cluster::PredictionClust], depending on argument `type`:
+#' Visualizations for [mlr3cluster::PredictionClust].
+#' The argument `type` controls what kind of plot is drawn.
+#' Possible choices are:
 #'
-#' * `"scatter"` (default): scatterplot with correlation values
-#' and colored cluster assignments.
-#'
-#' * `"sil"`: Silhouette plot with mean silhouette value as
-#'   a reference line. Requires package \CRANpkg{ggfortify}.
-#'
-#' * `"pca"`: Perform PCA on data and color code cluster
-#'   assignments. Inspired by and uses [ggfortify::autoplot.kmeans].
+#' * `"scatter"` (default): scatterplot with correlation values and colored cluster assignments.
+#' * `"sil"`: Silhouette plot with mean silhouette value as the reference line.
+#'    Requires package \CRANpkg{ggfortify}.
+#' * `"pca"`: Perform PCA on data and color code cluster assignments.
+#'    Inspired by and uses [ggfortify::autoplot.kmeans].
 #'
 #' @param object ([mlr3cluster::PredictionClust]).
 #' @param task ([mlr3cluster::TaskClust]).
-#' @param row_ids row ids to subset task data to ensure that
-#' only the data used to make predictions are shown in plots.
+#' @param row_ids (`integer()`)
+#' Row ids to subset task data to ensure that only the data used to make predictions are shown in plots.
 #' @template param_type
-#' @param ... (`any`):
-#'   Additional arguments, passed down to the respective `geom`.
+#' @template param_theme
+#' @param ... (ignored).
 #'
-#' @return [ggplot2::ggplot()] object.
-#'
-#' @template section_theme
+#' @return [ggplot2::ggplot()].
 #'
 #' @references
 #' `r format_bib("ggfortify")`
@@ -41,7 +38,7 @@
 #'   head(fortify(object))
 #'   autoplot(object, task)
 #' }
-autoplot.PredictionClust = function(object, task, row_ids = NULL, type = "scatter", ...) { # nolint
+autoplot.PredictionClust = function(object, task, row_ids = NULL, type = "scatter", theme = theme_minimal(), ...) { # nolint
   assert_string(type)
 
   switch(type,
@@ -60,12 +57,10 @@ autoplot.PredictionClust = function(object, task, row_ids = NULL, type = "scatte
       data$row_id = NULL
       data$partition = factor(data$partition)
 
-      GGally::ggscatmat(data, color = "partition", ...) +
-        apply_theme(list(
-          scale_color_viridis_d("Cluster", end = 0.8),
-          theme_mlr3() +
-            theme(axis.title.x.bottom = element_blank(), axis.title.y.left = element_blank())
-        ))
+      GGally::ggscatmat(data, color = "partition") +
+        scale_color_viridis_d("Cluster", end = 0.8, alpha = 0.8) +
+        theme +
+        theme(axis.title.x.bottom = element_blank(), axis.title.y.left = element_blank())
     },
 
     "sil" = {
@@ -75,11 +70,9 @@ autoplot.PredictionClust = function(object, task, row_ids = NULL, type = "scatte
       d = stats::dist(task$data(rows = row_ids))
       sil = cluster::silhouette(object$data$partition, d)
 
-      ggplot2::autoplot(sil, ...) +
-        apply_theme(list(
-          scale_fill_viridis_d("Cluster", end = 0.8),
-          theme_mlr3()
-        ))
+      ggplot2::autoplot(sil, colour = "#000000") +
+        scale_fill_viridis_d("Cluster", end = 0.8, alpha = 0.8) +
+        theme
     },
 
     "pca" = {
@@ -97,11 +90,10 @@ autoplot.PredictionClust = function(object, task, row_ids = NULL, type = "scatte
       plot_data = merge(task_data, d, by = "row_ids")
       ggplot2::autoplot(stats::prcomp(task_data[, -"row_ids"]),
         data = plot_data,
-        colour = "cluster", ...) +
-        apply_theme(list(
-          scale_color_viridis_d("Cluster", end = 0.8),
-          theme_mlr3()
-        ))
+        colour = "cluster",
+        size = 3) +
+        scale_color_viridis_d("Cluster", end = 0.8, alpha = 0.8) +
+        theme
     },
 
     stopf("Unknown plot type '%s'", type)
